@@ -345,7 +345,7 @@ class NXSort():
             self.track_list.append(trk_obj)
             self.update_dict['new_ids'].append(trk_id)
             
-            if self.use_feature and embeddings is not None:
+            if self.use_feature and len(embeddings) > 0:
                 feature = embeddings[i]
                 trk_obj.push_feature(feature)
 
